@@ -9,7 +9,6 @@
 
 #include "ldap_debug.h"
 
-
 using namespace KLDAP;
 
 class Q_DECL_HIDDEN LdapUrl::LdapUrlPrivate
@@ -64,11 +63,11 @@ LdapUrl::~LdapUrl()
 
 void LdapUrl::setDn(const LdapDN &dn)
 {
-    QString tmp = dn.toString();
+    const QString tmp = dn.toString();
     if (tmp.startsWith(QLatin1Char('/'))) {
         setPath(tmp);
     } else {
-        setPath(QLatin1Char('/')  + tmp);
+        setPath(QLatin1Char('/') + tmp);
     }
 }
 
@@ -137,16 +136,14 @@ LdapUrl::Extension LdapUrl::extension(const QString &key) const
 
 QString LdapUrl::extension(const QString &key, bool &critical) const
 {
-    Extension ext;
-
-    ext = extension(key);
+    const Extension ext = extension(key);
     critical = ext.critical;
     return ext.value;
 }
 
 void LdapUrl::setExtension(const QString &key, const LdapUrl::Extension &ext)
 {
-    d->m_extensions[ key ] = ext;
+    d->m_extensions[key] = ext;
     updateQuery();
 }
 
@@ -233,7 +230,7 @@ void LdapUrl::parseQuery()
     }
 
     // split into a list
-    QStringList url_items = q.split(QLatin1Char('?'));
+    const QStringList url_items = q.split(QLatin1Char('?'));
 
     d->m_attributes.clear();
     d->m_scope = Base;
@@ -242,15 +239,10 @@ void LdapUrl::parseQuery()
 
     int i = 0;
     QStringList::const_iterator end(url_items.constEnd());
-    for (QStringList::const_iterator it = url_items.constBegin();
-         it != end; ++it, i++) {
+    for (QStringList::const_iterator it = url_items.constBegin(); it != end; ++it, i++) {
         switch (i) {
         case 0:
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-            d->m_attributes = (*it).split(QLatin1Char(','), QString::SkipEmptyParts);
-#else
             d->m_attributes = (*it).split(QLatin1Char(','), Qt::SkipEmptyParts);
-#endif
             break;
         case 1:
             if ((*it) == QLatin1String("sub")) {
@@ -263,19 +255,14 @@ void LdapUrl::parseQuery()
             d->m_filter = fromPercentEncoding((*it).toLatin1());
             break;
         case 3:
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-            extensions = (*it).split(QLatin1Char(','), QString::SkipEmptyParts);
-#else
             extensions = (*it).split(QLatin1Char(','), Qt::SkipEmptyParts);
-#endif
             break;
         }
     }
 
     QString name, value;
     QStringList::const_iterator end2(extensions.constEnd());
-    for (QStringList::const_iterator it = extensions.constBegin();
-         it != end2; ++it) {
+    for (QStringList::const_iterator it = extensions.constBegin(); it != end2; ++it) {
         ext.critical = false;
         name = fromPercentEncoding((*it).section(QLatin1Char('='), 0, 0).toLatin1()).toLower();
         value = fromPercentEncoding((*it).section(QLatin1Char('='), 1).toLatin1());
